@@ -24,4 +24,4 @@ plugins = load_plugins()
 
 def run():
 
-    cli(obj=DevCliContext.from_config_file())
\ No newline at end of file
+    cli(obj={})
\ No newline at end of file
