@@ -1,6 +1,8 @@
 import importlib
+import logging
 import os
 import pkgutil
+from pathlib import Path
 
 import yaml
 from cachetools.func import lru_cache
@@ -26,7 +28,20 @@ class DevCliContext:
         print(self.plugins)
         return [getattr(plugin, script_name) for plugin in self.plugins.values() if hasattr(plugin, script_name)]
 
-    def from_config_file():
+    def from_config_file(profile):
         with open(os.path.join(os.getenv("HOME"), '.devcli_config')) as file:
             config = yaml.load(file)
-            return DevCliContext(config)
+            
+        
+        if profile :
+            with open(os.path.join(os.getenv("HOME"), f'.devcli_config_{profile}')) as file2:
+                config.update(yaml.load(file2))
+
+        print(config)
+        path = Path('.devcli_config')
+        print(path.absolute())
+        
+        
+        return DevCliContext(config)
+
+
